var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __async = (__this, __arguments, generator) => {
  return new Promise((resolve, reject) => {
    var fulfilled = (value) => {
      try {
        step(generator.next(value));
      } catch (e) {
        reject(e);
      }
    };
    var rejected = (value) => {
      try {
        step(generator.throw(value));
      } catch (e) {
        reject(e);
      }
    };
    var step = (x) => x.done ? resolve(x.value) : Promise.resolve(x.value).then(fulfilled, rejected);
    step((generator = generator.apply(__this, __arguments)).next());
  });
};

// src/index.ts
import path3 from "path";
import { addTrailingSlash } from "@rspress/shared";
import { logger as logger2 } from "@rspress/shared/logger";

// src/utils.ts
import path from "path";
import fs from "@rspress/shared/fs-extra";
import { logger } from "@rspress/shared/logger";
import { loadFrontMatter } from "@rspress/shared/node-utils";
function detectFilePath(rawPath) {
  return __async(this, null, function* () {
    const extensions = [".mdx", ".md", ".tsx", ".jsx", ".ts", ".js"];
    let realPath = rawPath;
    const filename = path.basename(rawPath);
    if (filename.indexOf(".") === -1) {
      const pathWithExtension = extensions.map((ext) => `${rawPath}${ext}`);
      const pathExistInfo = yield Promise.all(
        pathWithExtension.map((p) => fs.pathExists(p))
      );
      realPath = pathWithExtension.find((_, i) => pathExistInfo[i]);
    }
    return realPath;
  });
}
function extractTitleAndOverviewHeaders(filePath, rootDir) {
  return __async(this, null, function* () {
    const realPath = yield detectFilePath(filePath);
    if (!realPath) {
      logger.warn(
        `Can't find the file: ${filePath}, please check it in "${path.join(
          path.dirname(filePath),
          "_meta.json"
        )}".`
      );
      return {
        title: "",
        overviewHeaders: void 0
      };
    }
    const content = yield fs.readFile(realPath, "utf-8");
    const fileNameWithoutExt = path.basename(realPath, path.extname(realPath));
    const h1RegExp = /^#\s+(.*)$/m;
    const match = content.match(h1RegExp);
    const { frontmatter } = loadFrontMatter(content, filePath, rootDir);
    return {
      title: frontmatter.title || (match == null ? void 0 : match[1]) || fileNameWithoutExt,
      overviewHeaders: frontmatter.overviewHeaders
    };
  });
}
function combineWalkResult(walks, versions) {
  return walks.reduce(
    (acc, cur, curIndex) => ({
      nav: __spreadProps(__spreadValues({}, acc.nav), {
        [versions[curIndex] || "default"]: cur.nav
      }),
      sidebar: __spreadValues(__spreadValues({}, acc.sidebar), cur.sidebar)
    }),
    {
      nav: {},
      sidebar: {}
    }
  );
}

// src/walk.ts
import path2 from "path";
import fs2 from "@rspress/shared/fs-extra";
import {
  slash,
  withBase,
  isExternalUrl
} from "@rspress/shared";
function scanSideMeta(workDir, rootDir, docsDir, routePrefix) {
  return __async(this, null, function* () {
    const addRoutePrefix = (link) => `${routePrefix}${link}`;
    const metaFile = path2.resolve(workDir, "_meta.json");
    const relativePath = slash(path2.relative(rootDir, workDir));
    let sideMeta;
    try {
      sideMeta = yield fs2.readJSON(metaFile, "utf8");
    } catch (e) {
      const subItems = yield fs2.readdir(workDir);
      sideMeta = (yield Promise.all(
        subItems.map((item) => __async(this, null, function* () {
          if (item === "_meta.json") {
            return null;
          }
          const stat = yield fs2.stat(path2.join(workDir, item));
          if (stat.isDirectory()) {
            return {
              type: "dir",
              name: item,
              label: item
            };
          }
          return item;
        }))
      )).filter(Boolean);
    }
    const sidebarFromMeta = yield Promise.all(
      sideMeta.map((metaItem) => __async(this, null, function* () {
        if (typeof metaItem === "string") {
          const { title, overviewHeaders: overviewHeaders2 } = yield extractTitleAndOverviewHeaders(
            path2.resolve(workDir, metaItem),
            rootDir
          );
          const pureLink2 = `${relativePath}/${metaItem.replace(/\.mdx?$/, "")}`;
          return {
            text: title,
            link: addRoutePrefix(pureLink2),
            overviewHeaders: overviewHeaders2,
            _fileKey: path2.relative(docsDir, path2.join(workDir, metaItem))
          };
        }
        const {
          type = "file",
          name,
          label = "",
          collapsible,
          collapsed,
          link,
          tag,
          dashed,
          overviewHeaders
        } = metaItem;
        const pureLink = `${relativePath}/${name == null ? void 0 : name.replace(/\.mdx?$/, "")}`;
        if (type === "file") {
          const titleAndOverviewHeaders = yield extractTitleAndOverviewHeaders(
            path2.resolve(workDir, name),
            rootDir
          );
          const title = label || titleAndOverviewHeaders.title;
          const realPath = yield detectFilePath(path2.resolve(workDir, name));
          return {
            text: title,
            link: addRoutePrefix(pureLink),
            tag,
            overviewHeaders: titleAndOverviewHeaders.overviewHeaders ? titleAndOverviewHeaders.overviewHeaders : overviewHeaders,
            _fileKey: realPath ? path2.relative(docsDir, realPath) : ""
          };
        }
        if (type === "dir") {
          const subDir = path2.resolve(workDir, name);
          const subSidebar = yield scanSideMeta(
            subDir,
            rootDir,
            docsDir,
            routePrefix
          );
          const realPath = yield detectFilePath(subDir);
          return {
            text: label,
            collapsible,
            collapsed,
            items: subSidebar,
            link: realPath ? addRoutePrefix(pureLink) : "",
            tag,
            overviewHeaders,
            _fileKey: realPath ? path2.relative(docsDir, realPath) : ""
          };
        }
        if (type === "divider") {
          return { dividerType: dashed ? "dashed" : "solid" };
        }
        if (type === "section-header") {
          return { sectionHeaderText: label, tag };
        }
        return {
          text: label,
          link: isExternalUrl(link) ? link : withBase(link, routePrefix),
          tag
        };
      }))
    );
    return sidebarFromMeta;
  });
}
function walk(workDir, routePrefix = "/", docsDir) {
  return __async(this, null, function* () {
    const rootMetaFile = path2.resolve(workDir, "_meta.json");
    let navConfig;
    try {
      navConfig = yield fs2.readJSON(rootMetaFile, "utf8");
    } catch (e) {
      navConfig = [];
    }
    navConfig.forEach((navItem) => {
      if ("items" in navItem) {
        navItem.items.forEach((item) => {
          if ("link" in item && !isExternalUrl(item.link)) {
            item.link = withBase(item.link, routePrefix);
          }
        });
      }
      if ("link" in navItem && !isExternalUrl(navItem.link)) {
        navItem.link = withBase(navItem.link, routePrefix);
      }
    });
    const subDirs = (yield fs2.readdir(workDir)).filter(
      (v) => fs2.statSync(path2.join(workDir, v)).isDirectory() && v !== "node_modules"
    );
    const sidebarConfig = {};
    for (const subDir of subDirs) {
      const sidebarGroupKey = `${routePrefix}${subDir}`;
      sidebarConfig[sidebarGroupKey] = yield scanSideMeta(
        path2.join(workDir, subDir),
        workDir,
        docsDir,
        routePrefix
      );
    }
    return {
      nav: navConfig,
      sidebar: sidebarConfig
    };
  });
}

// src/index.ts
function processLocales(langs, versions, root, defaultLang, defaultVersion) {
  return Promise.all(
    langs.map((lang) => __async(this, null, function* () {
      const walks = versions.length ? yield Promise.all(
        versions.map((version) => {
          const routePrefix = addTrailingSlash(
            `${version === defaultVersion ? "" : `/${version}`}${lang === defaultLang ? "" : `/${lang}`}`
          );
          return walk(path3.join(root, version, lang), routePrefix, root);
        })
      ) : [
        yield walk(
          path3.join(root, lang),
          addTrailingSlash(lang === defaultLang ? "" : `/${lang}`),
          root
        )
      ];
      return combineWalkResult(walks, versions);
    }))
  );
}
function pluginAutoNavSidebar() {
  return {
    name: "auto-nav-sidebar",
    config(config) {
      return __async(this, null, function* () {
        var _a2;
        config.themeConfig = config.themeConfig || {};
        config.themeConfig.locales = config.themeConfig.locales || config.locales || [];
        const langs = config.themeConfig.locales.map((locale) => locale.lang);
        const hasLocales = langs.length > 0;
        const hasLang = Boolean(config.lang);
        const versions = ((_a2 = config.multiVersion) == null ? void 0 : _a2.versions) || [];
        const defaultLang = config.lang || "";
        const { default: defaultVersion = "" } = config.multiVersion || {};
        if (hasLocales) {
          const metaInfo = yield processLocales(
            langs,
            versions,
            config.root,
            defaultLang,
            defaultVersion
          );
          config.themeConfig.locales = config.themeConfig.locales.map(
            (item, index) => __spreadValues(__spreadValues({}, item), metaInfo[index])
          );
        } else {
          if (hasLang) {
            logger2.error(
              "`lang` is configured but `locales` not, thus `@rspress/plugin-auto-nav-sidebar` can not auto generate navbar level config correctly!\nplease check your config file"
            );
            return config;
          }
          const walks = versions.length ? yield Promise.all(
            versions.map((version) => {
              const routePrefix = addTrailingSlash(
                version === defaultVersion ? "" : `/${version}`
              );
              return walk(
                path3.join(config.root, version),
                routePrefix,
                config.root
              );
            })
          ) : [yield walk(config.root, "/", config.root)];
          const combined = combineWalkResult(walks, versions);
          config.themeConfig = __spreadValues(__spreadValues({}, config.themeConfig), combined);
        }
        return config;
      });
    }
  };
}
export {
  pluginAutoNavSidebar
};

//# sourceMappingURL=index.js.map